/*  pulsard - monitor MGE Pulsar UPS
 * 
 *  adapted from : 
 *  Utility functions for the gPhoto Canon PowerShot A5(Z)/A50 driver.
 *
 *  Copyright (C) 2000 Philippe Marzouk <philm@users.sourceforge.net>
 *  All rights reserved.
 *
 */

/*
 *		       GNU GENERAL PUBLIC LICENSE
 *			  Version 2, June 1991
 *
 *  Copyright (C) 1989, 1991 Free Software Foundation, Inc.
 *			     675 Mass Ave, Cambridge, MA 02139, USA
 *  Everyone is permitted to copy and distribute verbatim copies
 *  of this license document, but changing it is not allowed.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

/****************************************************************************
 *
 * File: util.c 
 *
 *
 *
 ****************************************************************************/

/****************************************************************************
 *
 * include files
 *
 ****************************************************************************/

#include <stdio.h>
#include <stdarg.h>

/*****************************************************************************
 *
 * dump_hex
 *
 * Dumps a memory area as hex on the screen.
 *
 * msg  - Info message for the dump
 * buf  - the memory buffer to dump
 * len  - length of the buffer
 *
 ****************************************************************************/


#define NIBBLE(_i)    (((_i) < 10) ? '0' + (_i) : 'A' + (_i) - 10)

void dump_hex(const char *msg, const unsigned char *buf, int len)
{
    int i;
    int nlocal;
    const unsigned char *pc;
    char *out;
    const unsigned char *start;
    char c;
    char line[100];

      start = buf;
      
#if 0
      if (len > 160)
	{
	  fprintf(stderr,"dump n:%d --> 160\n", len);
	  len = 160;
	}
#endif
      
      fprintf(stderr,"%s: (%d bytes)\n", msg, len);
      while (len > 0)
	{
	  sprintf(line, "%08x: ", buf - start);
	  out = line + 10;
	  
	  for (i = 0, pc = buf, nlocal = len; i < 16; i++, pc++)
	    {
	      if (nlocal > 0)
		{
		  c = *pc;
		  
		  *out++ = NIBBLE((c >> 4) & 0xF);
		  *out++ = NIBBLE(c & 0xF);
		  
		  nlocal--;
		}
	      else
		{
		  *out++ = ' ';
		  *out++ = ' ';
		}			/* end else */
	      
	      *out++ = ' ';
	    }			/* end for */
	  
	  *out++ = '-';
	  *out++ = ' ';
	  
	  for (i = 0, pc = buf, nlocal = len;
	       (i < 16) && (nlocal > 0);
	       i++, pc++, nlocal--)
	    {
	      c = *pc;
	      
	      if ((c < ' ') || (c >= 126))
		{
		  c = '.';
		}
	      
	      *out++ = c;
	    }			/* end for */
	  
	  *out++ = 0;
	  
	  fprintf(stderr,"%s\n", line);
	  
	  buf += 16;
	  len -= 16;
	}				/* end while */
}				/* end dump */

void debug_message(const char * msg, ...)
{
  va_list ap;
  

    va_start(ap, msg);
    vfprintf(stderr,msg, ap);
    va_end(ap);
}
    
/****************************************************************************
 *
 * End of file: util.c
 *
 ****************************************************************************/
